@@ -26,10 +26,9 @@ extern "C" {
 
 /** The public API declaration. */
 
-/* __MINGW32__ definition added for Haskell yaml package */
 #if defined(__MINGW32__)
 #   define  YAML_DECLARE(type)  type
-#elif _WIN32
+#elif defined(WIN32)
 #   if defined(YAML_DECLARE_STATIC)
 #       define  YAML_DECLARE(type)  type
 #   elif defined(YAML_DECLARE_EXPORT)
@@ -1092,7 +1091,7 @@ typedef struct yaml_parser_s {
     yaml_error_type_t error;
     /** Error description. */
     const char *problem;
-    /** The byte about which the problem occured. */
+    /** The byte about which the problem occurred. */
     size_t problem_offset;
     /** The problematic value (@c -1 is none). */
     int problem_value;
